@@ -1,3 +1,6 @@
+from typing import TypeVar, Generic
+
+from django.db.models import Model
 from rest_framework.views import APIView
 
 from dry_django.contrib.rest_framework.mixins import (
@@ -22,16 +25,24 @@ class DefaultAPIView(ApiDefaultMixin, APIView):
 #  Generic Dry Django views
 ###################################
 
+_DjangoModelTypeVar = TypeVar("_DjangoModelTypeVar", bound=Model)
 
-class ModelListAPIView(ModelListAPIMixin, DefaultAPIView):
+
+class ModelListAPIView(ModelListAPIMixin, DefaultAPIView, Generic[_DjangoModelTypeVar]):
     pass
 
 
-class ModelListCreateAPIView(ModelListAPIMixin, ModelCreateAPIMixin, DefaultAPIView):
+class ModelListCreateAPIView(
+    ModelListAPIMixin, ModelCreateAPIMixin[_DjangoModelTypeVar], DefaultAPIView, Generic[_DjangoModelTypeVar]
+):
     pass
 
 
 class ModelRetrieveUpdateDestroyAPIView(
-    ModelRetrieveAPIMixin, ModelUpdateAPIMixin, ModelDestroyAPIMixin, DefaultAPIView
+    ModelRetrieveAPIMixin[_DjangoModelTypeVar],
+    ModelUpdateAPIMixin[_DjangoModelTypeVar],
+    ModelDestroyAPIMixin[_DjangoModelTypeVar],
+    DefaultAPIView,
+    Generic[_DjangoModelTypeVar],
 ):
     pass
